function giK = locgiarray(k, gi,NK,locpdeg)
% prepare auxiliary array of global indices in the element k
% INPUT
%  k ... index of the element
%  gi ... Ntri-by-7  global indices to the stiffness matrix
%     if k is an index of an element then
%     gi(k,1:3) = indices of the three vertices
%     gi(k,4:6) = the first indices of the edge functions
%     gi(k,7)   = the first index of the bubble functions
%  NK ... number of shapefunctions in the element k (coputed from pdeg)
%  locpdeg ... 1-by-4 vector of polynomial degrees in the element
%          locpdeg(1) degree of the interior;  locpdeg(2:4) degrees of the edges
% OUTPUT
%  giK ... NK-by-1  giK(i)==global index (to the stiffness matrix) of the i-th shapefunction

  giK = zeros(NK,1);
  % vertex indices
  giK(1:3) = gi(k,1:3);  
  nK = 3;
  % edge indices
  for edge=1:3 
    for i=1:locpdeg(1+edge)-1
      nK=nK+1;
      if (gi(k,3+edge) > 0)  % interior edge
        giK(nK) = gi(k,3+edge)+i-1;
      else 
        giK(nK) = gi(k,3+edge); % boundary edge
      end
    end % for i
  end % for edge
  % bubble indices
  for i=1:(locpdeg(1)-1)*(locpdeg(1)-2)/2
    nK=nK+1;
    giK(nK) = gi(k,7)+i-1;
  end % for i

end % function
