function [rtri,rx,ry] = unif_ref(tri,x,y)
% one uniform refinement of the triangulation given by tri,x,y
% the new vertices (midpoints of interior edges) are present twice in the new list of vertices
% x,y ... row vectors
% tri ... m by 3 matrix

Ntri = size(tri,1);
Nv = length(x);

rx = x;
ry = y;
rtri = [];

for k = 1 : Ntri
  iV1 = tri(k,1);
  iV2 = tri(k,2);
  iV3 = tri(k,3);
  iV4 = Nv+1;
  iV5 = Nv+2;
  iV6 = Nv+3;

  xV1 = x(iV1);
  xV2 = x(iV2);
  xV3 = x(iV3);
  xV4 = 0.5*(xV2 + xV3);
  xV5 = 0.5*(xV3 + xV1);
  xV6 = 0.5*(xV1 + xV2);

  yV1 = y(iV1);
  yV2 = y(iV2);
  yV3 = y(iV3);
  yV4 = 0.5*(yV2 + yV3);
  yV5 = 0.5*(yV3 + yV1);
  yV6 = 0.5*(yV1 + yV2);

  rtri = [rtri; iV1 iV6 iV5; iV2 iV4 iV6; iV3 iV5 iV4; iV4 iV5 iV6];
  rx = [rx xV4 xV5 xV6];
  ry = [ry yV4 yV5 yV6];
  Nv = Nv + 3;
end